@@ -3,4 +3,7 @@ __path__ = extend_path(__path__, __name__)
 
 from pubmedarticle import PubMedArticle
 from pubmedfetcher import PubMedFetcher
+from medgenfetcher import MedGenFetcher
+from medgenconcept import MedGenConcept
+
 
