@@ -40,47 +40,47 @@ class MedGenFetcher(Borg):
         if method=='eutils':
             import eutils.client as ec
             self.qs = ec.QueryService()
-            self.ids_by_term = self._eutils_ids_by_term
-            self.concept_by_id = self._eutils_concept_by_id
-            self.id_for_cuid = self._eutils_id_for_cuid
+            self.uids_by_term = self._eutils_uids_by_term
+            self.concept_by_uid = self._eutils_concept_by_uid
+            self.uid_for_cui = self._eutils_uid_for_cui
         else:
             raise NotImplementedError('coming soon: fetch from local medgen via medgen-mysql.')
 
-    def _eutils_ids_by_term(self, term):
+    def _eutils_uids_by_term(self, term):
         '''wraps results of an medgen efetch term lookup, returning IDs of related MedGenConcepts.
         
-        :return: list of medgen ids (strings)
+        :return: list of medgen uids (strings)
         '''
         # http://eutils.ncbi.nlm.nih.gov/entrez/eutils/esearch.fcgi?db=medgen&term=OCRL
         result = self.qs.esearch( { 'db': 'medgen', 'term': term } )
         dom = etree.fromstring(result)
-        ids = []
+        uids = []
         idlist = dom.find('IdList')
         for item in idlist.findall('Id'):
-            ids.append(item.text.strip())
-        return ids
+            uids.append(item.text.strip())
+        return uids
     
-    def _eutils_concept_by_id(self, id):
+    def _eutils_concept_by_uid(self, uid):
         '''wraps results of an esummary fcgi call to medgen when ID is known.
         
         :return: MedGenConcept object
         '''
         # http://eutils.ncbi.nlm.nih.gov/entrez/eutils/esummary.fcgi?db=medgen&id=336867
-        id = str(id)
-        result = self.qs.esummary( { 'db': 'medgen', 'id': id } )
+        uid = str(uid)
+        result = self.qs.esummary( { 'db': 'medgen', 'id': uid } )
         return MedGenConcept(result)
 
-    def _eutils_id_for_cuid(self, cuid):
-        '''given a ConceptID (cuid), return a medgen ID.'''
+    def _eutils_uid_for_cui(self, cui):
+        '''given a ConceptID (cui), return a medgen ID.'''
         #http://eutils.ncbi.nlm.nih.gov/entrez/eutils/esearch.fcgi?db=medgen&term=C0000039
-        if not cuid.startswith('C'):
+        if not cui.startswith('C'):
             raise MetaPubError('Invalid CUID: must start with C (e.g. C0000039)')
 
-        result = self.qs.esearch( { 'db': 'medgen', 'term': cuid } )
-        dom = etree.fromstring(result)
+        result = self.qs.esearch( { 'db': 'medgen', 'term': cui } )
+        root = etree.fromstring(result).getroottree()
         try:
-            cuid = dom.find('IdList').find('Id').strip()
+            uid = root.find('IdList').find('Id').text.strip()
         except AttributeError:
             raise MetaPubError('Invalid CUID: did not return MedGen id.')
-        return cuid
+        return uid
 
